@@ -2,9 +2,9 @@ module Unix::Exec
   include Beaker::CommandFactory
 
   # Reboots the host, comparing uptime values to verify success
-  # @param [Integer] wait_time How long to wait after sending the reboot 
+  # @param [Integer] wait_time How long to wait after sending the reboot
   #                            command before attempting to check in on the host
-  # @param [Integer] max_connection_tries How many times to retry connecting to 
+  # @param [Integer] max_connection_tries How many times to retry connecting to
   #                            host after reboot. Note that there is an fibbonacci
   #                            backoff when attempting retries so the time spent
   #                            waiting on this can grow quickly.
@@ -12,87 +12,106 @@ module Unix::Exec
   #
   # Will throw an exception RebootFailure if it fails
   def reboot(wait_time=10, max_connection_tries=9, uptime_retries=18)
-    begin
-      original_uptime = exec(Beaker::Command.new("uptime"))
-      original_uptime_str = parse_uptime original_uptime.stdout
-      original_uptime_int = uptime_int original_uptime_str
+    require 'time'
 
-      if self['platform'] =~ /solaris/
-        exec(Beaker::Command.new("reboot"), :expect_connection_failure => true)
-      else
-        exec(Beaker::Command.new("/sbin/shutdown -r now"), :expect_connection_failure => true)
+    attempts = 0
+
+    # Some systems don't support 'last -F reboot' but it has second granularity
+    boot_time_cmd = 'last -F reboot || who -b'
+
+    # Try to match all of the common formats for 'last' and 'who'
+    current_year = Time.now.strftime("%Y")
+    boot_time_regex = Regexp.new(%{((?:#{(Date::ABBR_DAYNAMES + Date::ABBR_MONTHNAMES).compact.join('|')}|#{current_year}).+?(\\d+:\\d+)+?(?::(\\d+).+?#{current_year})?)})
+
+    original_boot_time_str = nil
+    original_boot_time_line = nil
+    begin
+      attempts += 1
+      # Number of seconds to sleep before rebooting.
+      reboot_sleep = 1
+
+      original_boot_time_str = exec(Beaker::Command.new(boot_time_cmd), {:max_connection_tries => max_connection_tries, :silent => true}).stdout
+      original_boot_time_line = original_boot_time_str.lines.grep(/boot/).first
+
+      raise Beaker::Host::RebootWarning, "Could not find system boot time using '#{boot_time_cmd}': '#{original_boot_time_str}'" unless original_boot_time_line
+
+      original_boot_time_matches = original_boot_time_line.scan(boot_time_regex).last
+
+      raise Beaker::Host::RebootWarning, "Found no valid times in '#{original_boot_time_line}'" unless original_boot_time_matches
+
+      original_boot_time = Time.parse(original_boot_time_matches.first)
+
+      unless original_boot_time_matches.last
+        reboot_sleep = (61 - Time.now.strftime("%S").to_i)
       end
-    rescue Beaker::Host::CommandFailure => e
-      raise Beaker::Host::RebootFailure, "Command failed when attempting to reboot: #{e.message}"
-    rescue RuntimeError => e
-      raise Beaker::Host::RebootFailure, "Unexpected exception in reboot: #{e.message}"
+
+      @logger.notify("Sleeping #{reboot_sleep} seconds before rebooting")
+
+      sleep(reboot_sleep)
+
+      exec(Beaker::Command.new('/bin/systemctl reboot -i || reboot || /sbin/shutdown -r now'), :expect_connection_failure => true)
+    rescue ArgumentError => e
+      raise Beaker::Host::RebootFailure, "Unable to parse time: #{e.message}"
+    rescue Beaker::Host::RebootWarning => e
+      raise if attempts > uptime_retries
+      @logger.warn(e.message)
+      @logger.warn("Retrying #{uptime_retries - attempts} more times.")
+      retry
+    rescue StandardError => e
+      raise if attempts > uptime_retries
+      @logger.warn("Unexpected Exception: #{e.message}")
+      @logger.warn("Retrying #{uptime_retries - attempts} more times.")
+      @logger.warn(e.backtrace[0,3].join("\n"))
+      @logger.debug(e.backtrace.join("\n"))
+      retry
     end
 
     attempts = 0
     begin
+      attempts += 1
+
       # give the host a little time to shutdown
       @logger.debug("Waiting #{wait_time} for host to shut down.")
       sleep wait_time
 
-      #use uptime to check if the host has rebooted
-      current_uptime_exec = exec(Beaker::Command.new("uptime"), {:max_connection_tries => max_connection_tries, :silent => true})
-      current_uptime = current_uptime_exec.stdout
-      current_uptime_str = parse_uptime current_uptime
-      current_uptime_int = uptime_int current_uptime_str
-      unless original_uptime_int > current_uptime_int
-        raise Beaker::Host::RebootFailure, "Uptime did not reset. Reboot appears to have failed." 
+      # Accept all exit codes because this may fail due to the parallel nature of systemd
+      current_boot_time_str = exec(Beaker::Command.new(boot_time_cmd), {:max_connection_tries => max_connection_tries, :silent => true, :accept_all_exit_codes => true}).stdout
+      current_boot_time_line = current_boot_time_str.lines.grep(/boot/).first
+
+      raise Beaker::Host::RebootWarning, "Could not find system boot time using '#{boot_time_cmd}': '#{current_boot_time_str}'" unless current_boot_time_line
+
+      current_boot_time_matches = current_boot_time_line.scan(boot_time_regex).last
+
+      raise Beaker::Host::RebootWarning, "Found no valid times in '#{current_boot_time_line}'" unless current_boot_time_matches
+
+      current_boot_time = Time.parse(current_boot_time_matches.first)
+
+      @logger.debug("Original Boot Time: #{original_boot_time}")
+      @logger.debug("Current Boot Time: #{current_boot_time}")
+
+      # If this is *exactly* the same then there is really no good way to detect a reboot
+      if current_boot_time == original_boot_time
+        raise Beaker::Host::RebootFailure, "Boot time did not reset. Reboot appears to have failed."
       end
+    rescue ArgumentError => e
+      raise Beaker::Host::RebootFailure, "Unable to parse time: #{e.message}"
     rescue Beaker::Host::RebootFailure => e
-      attempts += 1
-      if attempts < uptime_retries
-        @logger.debug("Uptime did not reset. Will retry #{uptime_retries - attempts} more times.")
-        retry
-      else
-        raise
-      end
-    rescue Beaker::Host::CommandFailure => e
-      raise Beaker::Host::RebootFailure, "Command failed when attempting to reboot: #{e.message}"
-    rescue RuntimeError => e
-      raise Beaker::Host::RebootFailure, "Unexpected exception in reboot: #{e.message}"
+      raise
+    rescue Beaker::Host::RebootWarning => e
+      raise if attempts > uptime_retries
+      @logger.warn(e.message)
+      @logger.warn("Retrying #{uptime_retries - attempts} more times.")
+      retry
+    rescue StandardError => e
+      raise if attempts > uptime_retries
+      @logger.warn("Unexpected Exception: #{e.message}")
+      @logger.warn("Retrying #{uptime_retries - attempts} more times.")
+      @logger.warn(e.backtrace[0,3].join("\n"))
+      @logger.debug(e.backtrace.join("\n"))
+      retry
     end
   end
 
-  def uptime_int(uptime_str)
-    time_array = uptime_str.split(", ")
-    accumulated_mins = 0
-    time_array.each do |time_segment|
-      value, unit = time_segment.split
-      if unit.nil?
-        # 20:47 case: hours & mins
-        hours, mins = value.split(":")
-        accumulated_mins += (hours.to_i * 60 + mins.to_i)
-      elsif unit =~ /day(s)?/
-        accumulated_mins += (value.to_i * 1440) # 60 * 24 = 1440
-      elsif unit =~ /min(s)?/
-        accumulated_mins += value.to_i
-      else
-        raise ArgumentError, "can't parse uptime segment: #{time_segment}"
-      end
-    end
-
-    accumulated_mins
-  end
-
-  def parse_uptime(uptime)
-    # get String from up to users
-    # eg 19:52  up 14 mins, 2 users, load averages: 2.95 4.19 4.31
-    # 8:03 up 52 days, 20:47, 3 users, load averages: 1.36 1.42 1.40
-    # 22:19 up 54 days, 1 min, 4 users, load averages: 2.08 2.06 2.27
-    regexp = /.*up (.*)[[:space:]]+[[:digit:]]+ user.*/
-    result = uptime.match regexp
-    if self['platform'] =~ /solaris-/ && result[1].empty?
-      return "0 min"
-    end
-    raise "Couldn't parse uptime: #{uptime}" if result.nil?
-    
-    result[1].strip.chomp(",")
-  end
-
   def echo(msg, abs=true)
     (abs ? '/bin/echo' : 'echo') + " #{msg}"
   end
@@ -101,6 +120,16 @@ module Unix::Exec
     (abs ? '/bin/touch' : 'touch') + " #{file}"
   end
 
+  # Update ModifiedDate on a file
+  # @param [String] file Path to the file
+  # @param [String] timestamp Timestamp to set
+  def modified_at(file, timestamp = nil)
+    require 'date'
+    time = timestamp ? DateTime.parse("#{timestamp}") : DateTime.now
+    timestamp = time.strftime('%Y%m%d%H%M')
+    execute("/bin/touch -mt #{timestamp} #{file}")
+  end
+
   def path
     '/bin:/usr/bin'
   end
@@ -109,7 +138,9 @@ module Unix::Exec
     if self['platform'].include?('solaris') || self['platform'].include?('osx')
       execute("ifconfig -a inet| awk '/broadcast/ {print $2}' | cut -d/ -f1 | head -1").strip
     else
-      execute("ip a | awk '/global/{print$2}' | cut -d/ -f1 | #{self['hypervisor'] == 'vagrant' ? 'tail' : 'head'} -1").strip
+
+      pipe_cmd = "#{self['hypervisor']}".include?('vagrant') ? 'tail' : 'head'
+      execute("ip a | awk '/global/{print$2}' | cut -d/ -f1 | #{pipe_cmd} -1").strip
     end
   end
 
@@ -157,8 +188,8 @@ module Unix::Exec
   # This is for sles based hosts.
   # @param [String] env_file The ssh environment file to read from
   def mirror_env_to_profile_d env_file
-    if self[:platform] =~ /sles-/
-      @logger.debug("mirroring environment to /etc/profile.d on sles platform host")
+    if self[:platform] =~ /opensuse|sles-/
+      @logger.debug("mirroring environment to /etc/profile.d on opensuse/sles platform host")
       cur_env = exec(Beaker::Command.new("cat #{env_file}")).stdout
       shell_env = ''
       cur_env.each_line do |env_line|
@@ -253,7 +284,7 @@ module Unix::Exec
       exec(Beaker::Command.new("systemctl restart sshd.service"))
     when /el-|centos|fedora|redhat|oracle|scientific|eos/
       exec(Beaker::Command.new("/sbin/service sshd restart"))
-    when /sles/
+    when /opensuse|sles/
       exec(Beaker::Command.new("/usr/sbin/rcsshd restart"))
     when /solaris/
       exec(Beaker::Command.new("svcadm restart svc:/network/ssh:default"))
@@ -284,7 +315,7 @@ module Unix::Exec
       directory = tmpdir()
       exec(Beaker::Command.new("echo 'PermitUserEnvironment yes' | cat - /etc/ssh/sshd_config > #{directory}/sshd_config.permit"))
       exec(Beaker::Command.new("mv #{directory}/sshd_config.permit /etc/ssh/sshd_config"))
-    when /sles/
+    when /opensuse|sles/
       directory = tmpdir()
       exec(Beaker::Command.new("echo 'PermitUserEnvironment yes' | cat - /etc/ssh/sshd_config > #{directory}/sshd_config.permit"))
       exec(Beaker::Command.new("mv #{directory}/sshd_config.permit /etc/ssh/sshd_config"))
@@ -419,4 +450,29 @@ module Unix::Exec
     true
   end
 
+  #First path it finds for the command executable
+  #@param [String] command The command executable to search for
+  #
+  # @return [String] Path to the searched executable or empty string if not found
+  #
+  #@example
+  #  host.which('ruby')
+  def which(command)
+    unless @which_command
+      if execute('type -P true', :accept_all_exit_codes => true).empty?
+        if execute('which true', :accept_all_exit_codes => true).empty?
+          raise ArgumentError, "Could not find suitable 'which' command"
+        else
+          @which_command = 'which'
+        end
+      else
+        @which_command = 'type -P'
+      end
+    end
+
+    result = execute("#{@which_command} #{command}", :accept_all_exit_codes => true)
+    return '' if result.empty?
+
+    result
+  end
 end
