@@ -13,6 +13,7 @@ module Beaker
     SLEEPWAIT = 5
     TRIES = 5
     RHEL8_PACKAGES = ['curl', 'chrony']
+    FEDORA_PACKAGES = ['curl', 'chrony']
     UNIX_PACKAGES = ['curl', 'ntpdate']
     FREEBSD_PACKAGES = ['curl', 'perl5|perl']
     OPENBSD_PACKAGES = ['curl']
@@ -52,9 +53,9 @@ module Beaker
           logger.notify "NTP date succeeded on #{host}"
         else
           case
-          when host['platform'] =~ /el-8/
+          when host['platform'] =~ /el-8|fedora/
             ntp_command = "chronyc add server #{ntp_server} prefer trust;chronyc makestep;chronyc burst 1/2"
-          when host['platform'] =~ /sles-/
+          when host['platform'] =~ /opensuse-|sles-/
             ntp_command = "sntp #{ntp_server}"
           when host['platform'] =~ /cisco_nexus/
             ntp_server = host.exec(Command.new("getent hosts #{NTPSERVER} | head -n1 |cut -d \" \" -f1"), :acceptable_exit_codes => [0]).stdout
@@ -105,7 +106,7 @@ module Beaker
           check_and_install_packages_if_needed(host, RHEL8_PACKAGES)
         when host['platform'] =~ /sles-10/
           check_and_install_packages_if_needed(host, SLES10_PACKAGES)
-        when host['platform'] =~ /sles-/
+        when host['platform'] =~ /opensuse|sles-/
           check_and_install_packages_if_needed(host, SLES_PACKAGES)
         when host['platform'] =~ /debian/
           check_and_install_packages_if_needed(host, DEBIAN_PACKAGES)
@@ -126,7 +127,9 @@ module Beaker
           check_and_install_packages_if_needed(host, SOLARIS11_PACKAGES)
         when host['platform'] =~ /archlinux/
           check_and_install_packages_if_needed(host, ARCHLINUX_PACKAGES)
-        when host['platform'] !~ /debian|aix|solaris|windows|sles-|osx-|cumulus|f5-|netscaler|cisco_/
+        when host['platform'] =~ /fedora/
+          check_and_install_packages_if_needed(host, FEDORA_PACKAGES)
+        when host['platform'] !~ /debian|aix|solaris|windows|opensuse-|sles-|osx-|cumulus|f5-|netscaler|cisco_/
           check_and_install_packages_if_needed(host, UNIX_PACKAGES)
         end
       end
@@ -244,7 +247,7 @@ module Beaker
       report_and_raise(logger, e, "proxy_config")
     end
 
-    #Install EPEL on host or hosts with platform = /el-(5|6|7)/.  Do nothing on host or hosts of other platforms.
+    #Install EPEL on host or hosts with platform = /el-(6|7)/.  Do nothing on host or hosts of other platforms.
     # @param [Host, Array<Host>] host One or more hosts to act upon.  Will use individual host epel_url, epel_arch
     #                                 and epel_pkg before using defaults provided in opts.
     # @param [Hash{Symbol=>String}] opts Options to alter execution.
@@ -258,11 +261,10 @@ module Beaker
       debug_opt = opts[:debug] ? 'vh' : ''
       block_on host do |host|
         case
-        when el_based?(host) && ['5','6','7'].include?(host['platform'].version)
+        when el_based?(host) && ['6','7'].include?(host['platform'].version)
           result = host.exec(Command.new('rpm -qa | grep epel-release'), :acceptable_exit_codes => [0,1])
           if result.exit_code == 1
             url_base = opts[:epel_url]
-            url_base = opts[:epel_url_archive] if host['platform'].version == '5'
             host.install_package_with_rpm("#{url_base}/epel-release-latest-#{host['platform'].version}.noarch.rpm", '--replacepkgs', { :package_proxy => opts[:package_proxy] })
             #update /etc/yum.repos.d/epel.repo for new baseurl
             host.exec(Command.new("sed -i -e 's;#baseurl.*$;baseurl=#{Regexp.escape("#{url_base}/#{host['platform'].version}")}/\$basearch;' /etc/yum.repos.d/epel.repo"))
