@@ -73,6 +73,13 @@ module Beaker
           instance.deploy_package_repo(path,name,version)
         end
 
+        it 'calls #deploy_zyp_repo for opensuse systems' do
+          @opts = {'platform' => 'opensuse-is-me'}
+          expect(instance).to receive(:deploy_zyp_repo)
+          allow(File).to receive(:exists?).with(path).and_return(true)
+          instance.deploy_package_repo(path,name,version)
+        end
+
         it 'raises an error for unsupported systems' do
           @opts = {'platform' => 'windows-is-me'}
           allow(File).to receive(:exists?).with(path).and_return(true)
@@ -102,6 +109,14 @@ module Beaker
         expect( instance ).to receive(:exec).with('', :accept_all_exit_codes => true).and_return(generate_result("hello", {:exit_code => 0})).exactly(2).times
         expect( instance.check_for_package(pkg) ).to be === true
       end
+      it "checks correctly on opensuse" do
+        @opts = {'platform' => 'opensuse-is-me'}
+        pkg = 'sles_package'
+        expect( Beaker::Command ).to receive( :new ).with( /^rpmkeys.*nightlies.puppetlabs.com.*/, anything, anything ).and_return('').ordered.once
+        expect( Beaker::Command ).to receive(:new).with("zypper --gpg-auto-import-keys se -i --match-exact #{pkg}", [], {:prepend_cmds=>nil, :cmdexe=>false}).and_return('').ordered.once
+        expect( instance ).to receive(:exec).with('', :accept_all_exit_codes => true).and_return(generate_result("hello", {:exit_code => 0})).exactly(2).times
+        expect( instance.check_for_package(pkg) ).to be === true
+      end
 
       it "checks correctly on fedora" do
         @opts = {'platform' => 'fedora-is-me'}
@@ -297,6 +312,7 @@ module Beaker
         platforms = { 'solaris-10-x86_64' => ["solaris/10/#{puppet_collection}", "puppet-agent-#{puppet_agent_version}-1.i386.pkg.gz"],
                       'solaris-11-x86_64' => ["solaris/11/#{puppet_collection}", "puppet-agent@#{puppet_agent_version},5.11-1.i386.p5p"],
                       'sles-11-x86_64' => ["sles/11/#{puppet_collection}/x86_64", "puppet-agent-#{puppet_agent_version}-1.sles11.x86_64.rpm"],
+                      'opensuse-15-x86_64' => ["sles/15/#{puppet_collection}/x86_64", "puppet-agent-#{puppet_agent_version}-1.sles15.x86_64.rpm"],
                       'aix-6.1-power' => ["aix/6.1/#{puppet_collection}/ppc", "puppet-agent-#{puppet_agent_version}-1.aix6.1.ppc.rpm"],
                       'el-7-x86_64' => ["el/7/#{puppet_collection}/x86_64", "puppet-agent-#{puppet_agent_version}-1.el7.x86_64.rpm"],
                       'centos-7-x86_64' => ["el/7/#{puppet_collection}/x86_64", "puppet-agent-#{puppet_agent_version}-1.el7.x86_64.rpm"],
@@ -509,14 +525,9 @@ module Beaker
     describe '#install_local_package' do
       let( :platform      ) { @platform || 'fedora' }
       let( :version       ) { @version  || 6        }
-      let( :platform_mock ) {
-        mock = Object.new
-        allow( mock ).to receive( :to_array ) { [platform, version, '', ''] }
-        mock
-      }
 
       before :each do
-        allow( instance ).to receive( :[] ).with( 'platform' ) { platform_mock }
+        allow( instance ).to receive( :[] ).with( 'platform' ) { Beaker::Platform.new("#{platform}-#{version}-x86_64") }
       end
 
       it 'Fedora 22-39: uses dnf' do
@@ -530,7 +541,6 @@ module Beaker
 
       it 'Fedora 21 uses yum' do
         package_file = 'testing_456.yay'
-        platform_mock = Object.new
         [21].each do |version|
           @version = version
           expect( instance ).to receive( :execute ).with( /^yum.*#{package_file}$/ )
@@ -578,18 +588,13 @@ module Beaker
       let( :tar_file      ) { 'test.tar.gz'         }
       let( :base_dir      ) { '/base/dir/fake'      }
       let( :download_file ) { 'download_file.txt'   }
-      let( :platform_mock ) {
-        mock = Object.new
-        allow( mock ).to receive( :to_array ) { [platform, version, '', ''] }
-        mock
-      }
 
       before :each do
-        allow( instance ).to receive( :[] ).with( 'platform' ) { platform_mock }
+        allow( instance ).to receive( :[] ).with( 'platform' ) {  Beaker::Platform.new("#{platform}-#{version}-x86_64")  }
       end
 
       it 'rejects unsupported platforms' do
-        @platform = 'huawei'
+        @platform = 'cisco_nexus'
         expect {
           instance.uncompress_local_tarball( tar_file, base_dir, download_file )
         }.to raise_error(
@@ -605,6 +610,14 @@ module Beaker
         instance.uncompress_local_tarball( tar_file, base_dir, download_file )
       end
 
+      it 'untars the file given' do
+        @platform = 'opensuse'
+        expect( instance ).to receive( :execute ).with(
+          /^tar .* #{tar_file} .* #{base_dir}$/
+        )
+        instance.uncompress_local_tarball( tar_file, base_dir, download_file )
+      end
+
       context 'on solaris' do
 
         before :each do
