@@ -12,6 +12,7 @@ describe Beaker do
   let( :unix_only_pkgs ) { Beaker::HostPrebuiltSteps::UNIX_PACKAGES }
   let( :sles_only_pkgs ) { Beaker::HostPrebuiltSteps::SLES_PACKAGES }
   let( :rhel8_packages ) { Beaker::HostPrebuiltSteps::RHEL8_PACKAGES }
+  let( :fedora_packages) { Beaker::HostPrebuiltSteps::FEDORA_PACKAGES }
   let( :platform )       { @platform || 'unix' }
   let( :ip )             { "ip.address.0.0" }
   let( :stdout)          { @stdout || ip }
@@ -159,6 +160,15 @@ describe Beaker do
       subject.timesync(hosts, options)
     end
 
+    it "can sync time on Fedora hosts" do
+      hosts = make_hosts(:platform => 'fedora-32-x86_64')
+      expect(Beaker::Command).to receive(:new)
+        .with("chronyc add server #{ntpserver} prefer trust;chronyc makestep;chronyc burst 1/2")
+        .exactly(3)
+        .times
+      subject.timesync(hosts, options)
+    end
+
     it "can set time server on unix hosts" do
       hosts = make_hosts( { :platform => 'unix' } )
 
@@ -329,33 +339,6 @@ describe Beaker do
   context "add_el_extras" do
     subject { dummy_class.new }
 
-    it 'adds archived extras for el-5 hosts' do
-
-      hosts = make_hosts( { :platform => Beaker::Platform.new('el-5-arch'), :exit_code => 1 }, 2 )
-      hosts[1][:platform] = Beaker::Platform.new('oracle-5-arch')
-
-      expect( Beaker::Command ).to receive( :new ).with(
-        "rpm -qa | grep epel-release"
-      ).exactly( 2 ).times
-      hosts.each do |host|
-        expect(host).to receive( :install_package_with_rpm ).with(
-          "http://archive.fedoraproject.org/pub/archive/epel/epel-release-latest-5.noarch.rpm", "--replacepkgs", {:package_proxy => false}
-        ).once
-      end
-      expect( Beaker::Command ).to receive( :new ).with(
-        "sed -i -e 's;#baseurl.*$;baseurl=http://archive\\.fedoraproject\\.org/pub/archive/epel/5/$basearch;' /etc/yum.repos.d/epel.repo"
-      ).exactly( 2 ).times
-      expect( Beaker::Command ).to receive( :new ).with(
-        "sed -i -e '/mirrorlist/d' /etc/yum.repos.d/epel.repo"
-      ).exactly( 2 ).times
-      expect( Beaker::Command ).to receive( :new ).with(
-        "yum clean all && yum makecache"
-      ).exactly( 2 ).times
-
-      subject.add_el_extras( hosts, options )
-
-    end
-
     it 'adds extras for el-6 hosts' do
 
       hosts = make_hosts( { :platform => Beaker::Platform.new('el-6-arch'), :exit_code => 1 }, 4 )
@@ -464,6 +447,21 @@ describe Beaker do
 
     end
 
+    it "can validate opensuse hosts" do
+      @platform = 'opensuse-15-x86_x64'
+
+      hosts.each do |host|
+        sles_only_pkgs.each do |pkg|
+          expect( host ).to receive( :check_for_package).with( pkg ).once.and_return( false )
+          expect( host ).to receive( :install_package ).with( pkg ).once
+        end
+
+      end
+
+      subject.validate_host(hosts, options)
+
+    end
+
     it "can validate RHEL8 hosts" do
       @platform = 'el-8-x86_x64'
 
@@ -477,6 +475,19 @@ describe Beaker do
       subject.validate_host(hosts, options)
     end
 
+    it "can validate Fedora hosts" do
+      @platform = 'fedora-32-x86_64'
+
+      hosts.each do |host|
+        fedora_packages.each do |pkg|
+          expect(host).to receive(:check_for_package).with(pkg).once.and_return(false)
+          expect(host).to receive(:install_package).with(pkg).once
+        end
+      end
+
+      subject.validate_host(hosts, options)
+    end
+
     it 'skips validation on cisco hosts' do
       @platform = 'cisco_nexus-7-x86_64'
       expect( subject ).to receive( :check_and_install_packages_if_needed ).never
