@@ -325,7 +325,7 @@ module Beaker
         allow( result ).to receive( :exit_code ).and_return( 0 )
         allow( host ).to receive( :exec ).and_return( result )
 
-        expect( Beaker::Command ).to receive(:new).with("mkdir -p test/test/test")
+        expect( Beaker::Command ).to receive(:new).with("mkdir -p \"test/test/test\"")
         expect( host.mkdir_p('test/test/test') ).to be == true
 
       end
@@ -337,7 +337,7 @@ module Beaker
         allow( result ).to receive( :exit_code ).and_return( 0 )
         allow( host ).to receive( :exec ).and_return( result )
 
-        expect( Beaker::Command ).to receive(:new).with("mkdir -p test/test/test")
+        expect( Beaker::Command ).to receive(:new).with("mkdir -p \"test/test/test\"")
         expect( host.mkdir_p('test/test/test') ).to be == true
 
       end
@@ -349,7 +349,13 @@ module Beaker
         allow( result ).to receive( :exit_code ).and_return( 0 )
         allow( host ).to receive( :exec ).and_return( result )
 
-        expect( Beaker::Command ).to receive(:new).with("if not exist test\\test\\test (md test\\test\\test)")
+        expect( Beaker::Command ).to receive(:new).
+          with("powershell.exe", ["-ExecutionPolicy Bypass",
+                                  "-InputFormat None",
+                                  "-NoLogo",
+                                  "-NoProfile",
+                                  "-NonInteractive",
+                                  "-Command New-Item -Path 'test\\test\\test' -ItemType 'directory'"])
         expect( host.mkdir_p('test/test/test') ).to be == true
 
       end
